"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("../");
const units_EN_json_1 = __importDefault(require("../../nlp/units_EN.json"));
const units_FR_json_1 = __importDefault(require("../../nlp/units_FR.json"));
const models_FR_1 = require("./models_FR");
class ConversionsUtils {
    /**
     * Returns a list of units for the configured language.
     */
    static getUnits(lang) {
        switch (lang) {
            case __1.LANGUAGES.EN:
                return units_EN_json_1.default;
            case __1.LANGUAGES.FR:
                return units_FR_json_1.default;
        }
    }
    /**
     * Returns the key who has match the result
     */
    static getUnitKey(unit) {
        let returnUnit = unit;
        for (let i = 0; i < Object.keys(models_FR_1.globalUnit).length; i++) {
            if (Object.values(models_FR_1.globalUnit)[i].includes(unit)) {
                returnUnit = Object.keys(models_FR_1.globalUnit)[i];
                i = Object.keys(models_FR_1.globalUnit).length;
            }
        }
        return returnUnit;
    }
    /**
     * Normalizes a given amount.
     * @param val The amount to be normalized.
     */
    static normalizeAmount(lang, val) {
        let out;
        // Normalizing numeric word to number
        if (this.getUnits(lang).wordNumbers.hasOwnProperty(val)) {
            out = this.getUnits(lang).wordNumbers[val];
        }
        // Summing up moyen amounts (2-3 oeufs, 4-5 grammes, ...)
        const moyenRec = /(\d)?\-(\d)/gim;
        const matchesMoyen = moyenRec.exec(String(val));
        if (matchesMoyen) {
            if (matchesMoyen[1] && matchesMoyen[2]) {
                out = (Number(matchesMoyen[1]) + Number(matchesMoyen[2])) / 2;
            }
        }
        // Summing up mixed amounts (integer and fractions)
        const fractionRe = /(\d)?(.*)?(\d)\/(\d)/gim;
        const matches = fractionRe.exec(String(val));
        if (matches) {
            if (matches[1] && matches[3] && matches[4]) {
                out = Number(matches[1]) + Number(matches[3]) / Number(matches[4]);
            }
            else {
                out = Number(matches[3]) / Number(matches[4]);
            }
        }
        if (!out) {
            out = Number(val);
        }
        return out;
    }
}
exports.default = ConversionsUtils;
